@@ -154,16 +154,22 @@
 ( cd opt/kde/share/doc/HTML/sv/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kompare ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kompmgr ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kontact ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kontact ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konsole ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konsolekalendar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kanagram ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kanagram ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpackage ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/lilo-config ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/lilo-config ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/khelpcenter/quickstart ; rm -rf common )
@@ -180,6 +186,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kshisen ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ksirtet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ksirtet ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kdesvn-build ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kdesvn-build ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konquest ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/akregator ; rm -rf common )
@@ -194,8 +202,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kwallet ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kweather ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kxsldbg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kwifimanager ; rm -rf common )
@@ -208,114 +214,12 @@
 ( cd opt/kde/share/doc/HTML/sv/kioslave ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/knetattach ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kxconfig ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kxconfig ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 1.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 2.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/2.png 2.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 3.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/3.png 3.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 4.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/4.png 4.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 5.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/5.png 5.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 6.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/6.png 6.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 7.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/7.png 7.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 8.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/8.png 8.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 9.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom-left.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf appheader.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf top-middle.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom-right.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom1.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom2.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom-middle.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf top-left.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/top-left.png top-left.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bsd-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf web-docbottom.png )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/sv/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
 ( cd opt/kde/share/doc/HTML/sv/multisynk ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/multisynk ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kdm ; rm -rf common )
@@ -426,6 +330,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/artsbuilder ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kicker-applets ; rm -rf common )
@@ -440,8 +346,6 @@
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/domtreeviewer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/konq-plugins/smbmounter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/imgallery ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/khtmlsettings ; rm -rf common )
@@ -464,6 +368,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kalarm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kamera ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kaudiocreator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kaudiocreator ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdeprint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kasteroids ; rm -rf common )
@@ -474,8 +380,6 @@
 ( cd opt/kde/share/doc/HTML/sv/keduca ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kgamma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kgamma ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kmessedwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdevelop ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdevelop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kicker ; rm -rf common )
@@ -532,6 +436,10 @@
 ( cd opt/kde/share/doc/HTML/sv/kcharselect ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/quanta ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/quanta ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/superkaramba ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/ksmiletris ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/ksmiletris ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kuickshow ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kolourpaint ; rm -rf common )
@@ -558,6 +466,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kgeography ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kgeography ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kleopatra ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kjumpingcube ; rm -rf common )
@@ -568,14 +478,16 @@
 ( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kworldclock ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/blinken ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/blinken ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ksokoban ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ksokoban ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kteatime ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kmathtool ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kmathtool ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/knetworkconf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/pci ; rm -rf common )
@@ -600,12 +512,16 @@
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/partitions ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kinfocenter/cdinfo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/memory ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/ioports ; rm -rf common )
